#[non_exhaustive]pub enum FuseOverlayFsOption {
CloneFd,
MaxIdleThread(isize),
MaxThread(usize),
AllowOther,
AllowRoot,
SquashToRoot,
SquashToUid(usize),
SquashToGid(usize),
StaticNLink,
NoAcl,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CloneFd
Use separate fuse device fd for each thread
MaxIdleThread(isize)
The maximum number of idle worker threads allowed (default: -1)
MaxThread(usize)
The maximum number of worker threads allowed (default: 10)
AllowOther
Allow access by all users
AllowRoot
Allow access by root
SquashToRoot
Every file and directory is owned by the root user (0:0).
SquashToUid(usize)
Every file and directory is owned by the specified uid. It has higher precedence over squash_to_root.
SquashToGid(usize)
Every file and directory is owned by the specified gid. It has higher precedence over squash_to_root.
StaticNLink
Set st_nlink to static value 1 for all directories
NoAcl
Disable ACL support in the FUSE file system